==> cscec5b-storecloud-impl-3.0.0-20220803.113744-14-sources.jar: com/ejianc/business/storecloud/bean/WarehouseEntity.java <==
package com.ejianc.business.storecloud.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 仓库
 *
 * @author generator
 *
 */
 @TableName("ejc_storecloud_warehouse")
public class WarehouseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据号
    @TableField(value="org_id")
    private Long orgId; // 所属项目部
    @TableField(value="org_code")
    private String orgCode; // 所属项目部编码
    @TableField(value="org_name")
    private String orgName; //
    @TableField(value="project_id")
    private Long projectId; // 所属项目
    @TableField(value="project_name")
    private String projectName; //
    @TableField(value="project_code")
    private String projectCode; // 所属项目编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部上级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; //
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="state")
    private Integer state; // 仓库状态（1、启用，0、停用）
    @TableField(value="name")
    private String name; // 仓库名称
    @TableField(value="attr_flag")
    private Integer attrFlag; // 仓库属性 1-自购材；2-甲供材
    @TableField(value="total_mny")
    private BigDecimal totalMny; // 库存金额
    @TableField(value="default_flag")
    private Integer defaultFlag; // 是否默认：0-否；1-是
    @TableField(value="memo")
    private String memo; // 描述
    @TableField(value="qrcode")
    private String qrcode; // 二维码信息

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getAttrFlag() {
        return attrFlag;
    }

    public void setAttrFlag(Integer attrFlag) {
        this.attrFlag = attrFlag;
    }
    public BigDecimal getTotalMny() {
        return totalMny;
    }

    public void setTotalMny(BigDecimal totalMny) {
        this.totalMny = totalMny;
    }
    public Integer getDefaultFlag() {
        return defaultFlag;
    }

    public void setDefaultFlag(Integer defaultFlag) {
        this.defaultFlag = defaultFlag;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getQrcode() {
        return qrcode;
    }

    public void setQrcode(String qrcode) {
        this.qrcode = qrcode;
    }

}

==> cscec5b-storecloud-impl-3.0.1-20220809.070327-3-sources.jar: com/ejianc/business/storecloud/bean/WarehouseEntity.java <==
package com.ejianc.business.storecloud.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 仓库
 *
 * @author generator
 *
 */
 @TableName("ejc_storecloud_warehouse")
public class WarehouseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据号
    @TableField(value="org_id")
    private Long orgId; // 所属项目部
    @TableField(value="org_code")
    private String orgCode; // 所属项目部编码
    @TableField(value="org_name")
    private String orgName; //
    @TableField(value="project_id")
    private Long projectId; // 所属项目
    @TableField(value="project_name")
    private String projectName; //
    @TableField(value="project_code")
    private String projectCode; // 所属项目编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部上级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; //
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="state")
    private Boolean state; // 仓库状态（1、启用，0、停用）
    @TableField(value="warehouse_name")
    private String warehouseName; // 仓库名称
    @TableField(value="attr_flag")
    private Integer attrFlag; // 仓库属性 1-自购材；2-甲供材
    @TableField(value="total_mny")
    private BigDecimal totalMny; // 库存金额
    @TableField(value="default_flag")
    private Integer defaultFlag; // 是否默认：0-否；1-是
    @TableField(value="memo")
    private String memo; // 描述
    @TableField(value="qrcode")
    private String qrcode; // 二维码信息

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public void setState(Boolean state) {
        this.state = state;
    }

    public Boolean getState() {
        return state;
    }

    public String getWarehouseName() {
        return warehouseName;
    }

    public void setWarehouseName(String warehouseName) {
        this.warehouseName = warehouseName;
    }

    public Integer getAttrFlag() {
        return attrFlag;
    }

    public void setAttrFlag(Integer attrFlag) {
        this.attrFlag = attrFlag;
    }
    public BigDecimal getTotalMny() {
        return totalMny;
    }

    public void setTotalMny(BigDecimal totalMny) {
        this.totalMny = totalMny;
    }
    public Integer getDefaultFlag() {
        return defaultFlag;
    }

    public void setDefaultFlag(Integer defaultFlag) {
        this.defaultFlag = defaultFlag;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getQrcode() {
        return qrcode;
    }

    public void setQrcode(String qrcode) {
        this.qrcode = qrcode;
    }

}
